@@ -1635,7 +1635,7 @@ def extractRiseTimes(waveforms, low=0.1, high=0.1, smooth=None, pretrigger=800):
 	IMPORTANT NOTE: Risetimes from different methods are NOT necessarily equivalent. Do not assume they are.
 	
 	Parameters:
-		waves: np.ndarray
+		waveforms: np.ndarray
 			the waveforms to be processed. Expects 2d array of waveforms
 		pretrigger: int
 			the length of the pretrigger region to be averaged to 0
@@ -1656,7 +1656,7 @@ def extractRiseTimes(waveforms, low=0.1, high=0.1, smooth=None, pretrigger=800):
 		A np.ndarray of the risetimes as calculated by the method chosen
 	"""
 	if waveforms is not None:
-		if waves.shape[0] == 0:
+		if waveforms.shape[0] == 0:
 			return None
 		elif type(waveforms) == np.ndarray: #if it's a numpy array, convert it to dask so we can do this in parallel
 			waveforms = da.asarray(waveforms)
@@ -1674,7 +1674,7 @@ def extractRiseTimes(waveforms, low=0.1, high=0.1, smooth=None, pretrigger=800):
 		if high < low or high >=1:
 			print('invalid high parameter:', high, 'stopping execution')
 			return None
-		numwaves = waves.shape[0]
+		numwaves = waveforms.shape[0]
 		leftover = numwaves % batchsize
 		numbatches = int(numwaves / batchsize)
 		means = waveforms[:,0:pretrigger].mean(axis=1)
